@@ -1,3 +1,5 @@
+# SPDX-FileCopyrightText: Copyright (c) Fideus Labs LLC
+# SPDX-License-Identifier: MIT
 import sys
 from pathlib import Path
 import json
@@ -14,8 +16,8 @@ from ngff_zarr._zarr_kwargs import zarr_kwargs
 from zarr.storage import MemoryStore
 from deepdiff import DeepDiff
 
-test_data_ipfs_cid = "bafybeib2s7ls6yscm2uqxby5vbhbfsyxn3ev7soewi3hji4uiki7v6cbiy"
-test_data_sha256 = "58c0219f194cd976acee1ebd19ea78b03aada3f96a54302c8fb8515a349d9613"
+test_data_ipfs_cid = "bafybeif7tln62tvom3dzmqlr7y5rhdfgbdqmahuh5wdmz5ppmmgpkaboqu"
+test_data_sha256 = "4cdb01e49261348a37b38893f1607dfaac7378449c38420c824098064687ee66"
 
 test_dir = Path(__file__).resolve().parent
 extract_dir = "data"
@@ -31,7 +33,7 @@ def input_images():
     pooch.retrieve(
         fname="data.tar.gz",
         path=test_dir,
-        url="https://github.com/thewtex/ngff-zarr/releases/download/v0.13.2/ngff-zarr-0.13.2-test-data.tar.gz",
+        url="https://github.com/thewtex/ngff-zarr/releases/download/v0.18.0/ngff-zarr-0.18.0-test-data.tar.gz",
         # url=f"https://itk.mypinata.cloud/ipfs/{test_data_ipfs_cid}/data.tar.gz",
         # url=f"https://{test_data_ipfs_cid}.ipfs.w3s.link/ipfs/{test_data_ipfs_cid}/data.tar.gz",
         known_hash=f"sha256:{test_data_sha256}",
